@@ -793,7 +793,8 @@ static int addPrefixes(Header h, rpmRelocation *relocations, int numRelocations)
 	headerPutStringArray(h, RPMTAG_INSTPREFIXES, actualRelocations, numActual);
     }
     free(actualRelocations);
-    return numActual;
+    /* When any relocations are present there'll be more work to do */
+    return 1;
 }
 
 static void saveRelocs(Header h, rpmtd bnames, rpmtd dnames, rpmtd dindexes)
@@ -835,7 +836,8 @@ void rpmRelocateFileList(rpmRelocation *relocations, int numRelocations,
     int i, j;
     struct rpmtd_s bnames, dnames, dindexes, fmodes;
 
-    addPrefixes(h, relocations, numRelocations);
+    if (!addPrefixes(h, relocations, numRelocations))
+	return;
 
     if (!_printed) {
 	_printed = 1;
@@ -1124,15 +1126,17 @@ static int indexSane(rpmtd xd, rpmtd yd, rpmtd zd)
     uint32_t zc = rpmtdCount(zd);
 
     /* check that the amount of data in each is sane */
-    if (xc > 0 && yc > 0 && yc <= xc && zc == xc) {
-	uint32_t * i;
+    /* normally yc <= xc but larger values are not fatal (RhBug:1001553) */
+    if (xc > 0 && yc > 0 && zc == xc) {
+	uint32_t * i, nvalid = 0;
 	/* ...and that the indexes are within bounds */
 	while ((i = rpmtdNextUint32(zd))) {
 	    if (*i >= yc)
 		break;
+	    nvalid++;
 	}
 	/* unless the loop runs to finish, the data is broken */
-	sane = (i == NULL);
+	sane = (nvalid == zc);
     }
     return sane;
 }
