@@ -2,6 +2,7 @@
 
 #include <pwd.h>
 #include <grp.h>
+#include <netdb.h>
 #include <rpm/rpmlog.h>
 #include <rpm/rpmstring.h>
 
@@ -9,32 +10,6 @@
 #include "lib/rpmug.h"
 #include "debug.h"
 
-#define HASHTYPE strCache
-#define HTKEYTYPE const char *
-#include "lib/rpmhash.H"
-#include "lib/rpmhash.C"
-#undef HASHTYPE
-#undef HTKEYTYPE
-
-static strCache strStash = NULL;
-
-const char * rpmugStashStr(const char *str)
-{
-    const char *ret = NULL;
-    if (str) {
-	if (strStash == NULL) {
-	    strStash = strCacheCreate(64, rstrhash, strcmp,
-				      (strCacheFreeKey)rfree);
-	}
-	
-	if (!strCacheGetEntry(strStash, str, &ret)) {
-	    strCacheAddEntry(strStash, xstrdup(str));
-	    (void) strCacheGetEntry(strStash, str, &ret);
-	}
-    }
-    return ret;
-}
-
 /* 
  * These really ought to use hash tables. I just made the
  * guess that most files would be owned by root or the same person/group
@@ -192,11 +167,25 @@ const char * rpmugGname(gid_t gid)
     }
 }
 
+int rpmugInit(void)
+{
+    static int libsLoaded = 0;
+
+    if (!libsLoaded) {
+	(void) getpwnam("root");
+	endpwent();
+	(void) getgrnam("root");
+	endgrent();
+	(void) gethostbyname("localhost");
+    }
+
+    return 0;
+}
+
 void rpmugFree(void)
 {
     rpmugUid(NULL, NULL);
     rpmugGid(NULL, NULL);
     rpmugUname(-1);
     rpmugGname(-1);
-    strStash = strCacheFree(strStash);
 }
